@@ -73,11 +73,16 @@ extern WTYPE     get_gamma      (BitList *l);
 extern WTYPE     get_delta      (BitList *l);
 extern WTYPE     get_omega      (BitList *l);
 extern WTYPE     get_fib        (BitList *l);
+extern WTYPE     get_fibgen     (BitList *l, int m);
 extern WTYPE     get_levenstein (BitList *l);
 extern WTYPE     get_evenrodeh  (BitList *l);
+extern WTYPE     get_goldbach_g1(BitList *l);
+extern WTYPE     get_goldbach_g2(BitList *l);
 extern WTYPE     get_binword    (BitList *l, int k);
 extern WTYPE     get_baer       (BitList *l, int k);
 extern WTYPE     get_boldivigna (BitList *l, int k);
+extern WTYPE     get_comma      (BitList *l, int k);
+extern WTYPE     get_block_taboo(BitList *l, int bits, WTYPE taboo);
 extern WTYPE     get_rice_sub   (BitList *l, SV* self, SV* code, int k);
 extern WTYPE     get_golomb_sub (BitList *l, SV* self, SV* code, WTYPE m);
 extern WTYPE     get_gamma_rice (BitList *l, int k);
@@ -91,11 +96,16 @@ extern void      put_gamma      (BitList *l, WTYPE value);
 extern void      put_delta      (BitList *l, WTYPE value);
 extern void      put_omega      (BitList *l, WTYPE value);
 extern void      put_fib        (BitList *l, WTYPE value);
+extern void      put_fibgen     (BitList *l, int m, WTYPE value);
 extern void      put_levenstein (BitList *l, WTYPE value);
 extern void      put_evenrodeh  (BitList *l, WTYPE value);
+extern void      put_goldbach_g1(BitList *l, WTYPE value);
+extern void      put_goldbach_g2(BitList *l, WTYPE value);
 extern void      put_binword    (BitList *l, int k, WTYPE value);
 extern void      put_baer       (BitList *l, int k, WTYPE value);
 extern void      put_boldivigna (BitList *l, int k, WTYPE value);
+extern void      put_comma      (BitList *l, int k, WTYPE value);
+extern void      put_block_taboo(BitList *l, int bits, WTYPE taboo, WTYPE value);
 extern void      put_rice_sub   (BitList *l, SV* self, SV* code, int k, WTYPE value);
 extern void      put_golomb_sub (BitList *l, SV* self, SV* code, WTYPE m, WTYPE value);
 extern void      put_gamma_rice (BitList *l, int k, WTYPE value);
